// This file was generated by ecm_setup_version(): DO NOT EDIT!

#ifndef PHONON_VERSION_H
#define PHONON_VERSION_H

#define PHONON_VERSION_STRING "4.12.0"
#define PHONON_VERSION_MAJOR 4
#define PHONON_VERSION_MINOR 12
#define PHONON_VERSION_PATCH 0
#define PHONON_VERSION ((4<<16)|(12<<8)|(0))

#endif
